"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GridEventDispatcher = void 0;
/**
 * A class that implements this interface dispatches events about the grid
 */
class GridEventDispatcher {
    cellValueChangedListeners = [];
    /**
     * @param callback A function that should be called, when a cell value changes
     * @returns a function to unregister the callback
     */
    onCellValueChanged(callback) {
        this.cellValueChangedListeners.push(callback);
        return () => {
            this.cellValueChangedListeners = this.cellValueChangedListeners.filter((listener) => listener !== callback);
            return this.cellValueChangedListeners;
        };
    }
    /**
     * @param event The event that should be dispatched to all registered callbacks
     */
    dispatchCellValueChangedEvent(event) {
        for (const listener of this.cellValueChangedListeners) {
            listener(event);
        }
    }
}
exports.GridEventDispatcher = GridEventDispatcher;
