import { GridEventDispatcher } from './utils';
/**
 * A Cell is part of a grid. It contains meta information like its coordinates inside the grid and the corresponding value.
 */
export class Cell {
    id;
    row;
    col;
    _value;
    eventDispatcher;
    /**
     *
     * @param coordinate The coordinate in the grid
     * @param value The value of the cell
     */
    constructor(coordinate, value) {
        this.id = `cell|${coordinate.row}-${coordinate.col}`;
        this.row = coordinate.row;
        this.col = coordinate.col;
        this._value = value;
        this.eventDispatcher = new GridEventDispatcher();
    }
    /**
     * @returns the value of the cell
     */
    get value() {
        return this._value;
    }
    /**
     * Changes the value of the cell
     */
    set value(value) {
        const previousValue = this._value;
        this._value = value;
        this.eventDispatcher.dispatchCellValueChangedEvent({ cell: this, previousValue });
    }
    /**
     * @param callback A function that should be called, when the cell value changes
     * @returns a function to unregister the callback
     */
    onValueChanged(callback) {
        return this.eventDispatcher.onCellValueChanged(callback);
    }
}
