import type { Coordinate } from './Coordinate';
import { type CellValueChangedEvent } from './utils';
/**
 * A Cell is part of a grid. It contains meta information like its coordinates inside the grid and the corresponding value.
 */
export declare class Cell<Value> implements Coordinate {
    readonly id: string;
    readonly row: number;
    readonly col: number;
    private _value;
    private readonly eventDispatcher;
    /**
     *
     * @param coordinate The coordinate in the grid
     * @param value The value of the cell
     */
    constructor(coordinate: Coordinate, value: Value);
    /**
     * @returns the value of the cell
     */
    get value(): Value;
    /**
     * Changes the value of the cell
     */
    set value(value: Value);
    /**
     * @param callback A function that should be called, when the cell value changes
     * @returns a function to unregister the callback
     */
    onValueChanged(callback: (event: CellValueChangedEvent<Value>) => void): () => void;
}
//# sourceMappingURL=Cell.d.ts.map