import type { Cell } from '../Cell';
/**
 * This queue will return each cell only once
 */
export declare class UniqueCellQueue<Value, CellWithValue extends Cell<Value>> {
    private queue;
    private cellIds;
    /**
     * Adds a cell to the queue. If the given cell was in the queue already, it will not be added to the queue
     * @param cell The cell that should be added to the queue
     */
    add(cell: CellWithValue): void;
    /**
     * Adds an array of cells to the queue. If a given cell was in the queue already, it will not be added to the queue
     * @param cells The cells that should be added to the queue
     */
    addAll(cells: CellWithValue[]): void;
    /**
     * @param cell The cell that should never be added to the queue
     */
    ignore(cell: CellWithValue): void;
    /**
     * @returns true when the queue is not empty
     */
    hasNext(): boolean;
    /**
     * @returns The next cell in the queue
     * @throws {QueueIsEmptyError} when the queue has no more cells
     */
    getNext(): CellWithValue;
}
//# sourceMappingURL=UniqueCellQueue.d.ts.map